@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.64';
+our $VERSION = '0.65';
 
 use Dist::Zilla 6.0;
 
@@ -504,7 +504,9 @@ sub _explicit_prereq_plugins {
 
 sub _dist_uses_test2 {
     my $rule = Path::Iterator::Rule->new;
-    my $iter = $rule->file->contents_match(qr/^use Test2/m)->iter('t');
+    my $iter
+        = $rule->file->name(qr/\.(t|pm)/)->contents_match(qr/^use Test2/m)
+        ->iter('t');
 
     while ( my $file = $iter->() ) {
         return 1;
@@ -752,7 +754,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.64
+version 0.65
 
 =head1 DESCRIPTION
 
